# JoyCat

### This package visualizes the happiness of cats based on Japanese traditional lore.

In Japan, there is a saying, "When the autumn rains fall, the cat\'s face becomes three feet long. This means that the cat\'s face is longer and more joyful on rainy days than on sunny days in autumn, because the temperature is higher on rainy days. We assume that the more it rains, the more pleased the cat will be. Of course, this is limited to autumn. If it is autumn now, this will help. There is a lot going on in the world right now. But it does not matter to cats. If cats are happy, the world will be peaceful.

## Example

python JoyCat.py

output


![output](https://github.com/yuta08/JoyCat/blob/main/CatJoy.png)
